@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -974,7 +974,7 @@ header_parse (GMimeParser *parser, HeaderRaw **tail)
 				 header->offset, priv->user_data);
 #elif defined (HAVE_REGEX_H)
 	if (priv->have_regex &&
-	    !regexec (&priv->regex, header->name, 0, NULL, 0))
+	    !regexec (&priv->header_regex, header->name, 0, NULL, 0))
 		priv->header_cb (parser, header->name, header->value,
 				 header->offset, priv->user_data);
 #endif
